@@ -44,10 +44,19 @@ from update_checker import update_check
 from warnings import warn_explicit
 
 
-__version__ = '2.1.14'
+__version__ = '2.1.15'
+
+if os.environ.get('SERVER_SOFTWARE') is not None:
+    # Google App Engine information
+    # https://developers.google.com/appengine/docs/python/
+    platform_info = os.environ.get('SERVER_SOFTWARE')
+else:
+    # Standard platform information
+    platform_info = platform.platform(True)
+
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
-                                          platform.platform(True))
+                                          platform_info)
 
 MIN_IMAGE_SIZE = 128
 MAX_IMAGE_SIZE = 512000
@@ -644,8 +653,8 @@ class UnauthenticatedReddit(BaseReddit):
             data.update(captcha)
         return self.request_json(self.config['register'], data=data)
 
-    @decorators.depreciated(msg="Please use `get_comments(\'all\', ...)` "
-                                "instead.")
+    @decorators.deprecated(msg="Please use `get_comments(\'all\', ...)` "
+                               "instead.")
     def get_all_comments(self, *args, **kwargs):
         """Return a get_content generator for comments from `all` subreddits.
 
@@ -713,6 +722,7 @@ class UnauthenticatedReddit(BaseReddit):
             kwargs.setdefault('params', {})['t'] = period
         return self.get_content(url, *args, **kwargs)
 
+    @decorators.restrict_access(scope='modflair')
     def get_flair(self, subreddit, redditor):
         """Return the flair for a user on the given subreddit.
 
@@ -806,7 +816,7 @@ class UnauthenticatedReddit(BaseReddit):
         url = self.config['new_subreddits']
         return self.get_content(url, *args, **kwargs)
 
-    @decorators.depreciated(msg="Please use `get_popular_subreddits` instead.")
+    @decorators.deprecated(msg="Please use `get_popular_subreddits` instead.")
     def get_popular_reddits(self, *args, **kwargs):
         """Return a get_content generator for the most active subreddits."""
         return self.get_popular_subreddits(*args, **kwargs)
@@ -1832,7 +1842,7 @@ class MySubredditsMixin(AuthenticatedReddit):
         return self.get_content(self.config['my_mod_subreddits'], *args,
                                 **kwargs)
 
-    @decorators.depreciated(msg="Please use `get_my_subreddits` instead.")
+    @decorators.deprecated(msg="Please use `get_my_subreddits` instead.")
     def get_my_reddits(self, *args, **kwargs):
         """Return a get_content generator of subreddits."""
         return self.get_my_subreddits(*args, **kwargs)
